# Lab-Space

[![Downloads](https://static.pepy.tech/badge/lab-space)](https://pepy.tech/project/lab-space)

This package provides user friendly tools for running multi-threaded experiments, saving and analyzing data 


Please see our [Documentation](https://lab-space.readthedocs.io/en/latest/introduction.html), 
[Github source code](https://github.com/jaredjbeard/lab-space), 
and install from [PyPI](https://pypi.org/project/lab-space/)

Citation
--------
If you are using this in your work, please cite as

```
@misc{beard2023labspace,
    author = {Beard, Jared J.},
    title = {lab-space: A tool for easier experimentation},
    year = {2023},
    publisher = {GitHub},
    journal = {GitHub repository},
    howpublished = {\url{https://github.com/jaredjbeard/lab-space}},
}
```